{% extends "base.html" %}

{% block title -%}
    {{ article.title|striptags|breaking_spaces }} &mdash; {{ super() }}
{%- endblock %}

{% block html_lang %}{{ article.lang }}{% endblock %}

{% block meta %}
    {% if article.author %}
        <meta name="author" content="{{ article.author }}" />
    {% else %}
        <meta name="author" content="{{ AUTHOR }}" />
    {% endif %}
    {% if article.tags %}
        <meta name="keywords" content="{{ article.tags|join(',')|striptags }}" />
    {% endif %}
    {% if article.summary %}
        <meta name="description" content="{{ article.summary|striptags|escape }}" />
    {% endif %}
{% endblock %}

{% block opengraph %}
    {% if OPEN_GRAPH_FB_APP_ID %}
        <meta property="fb:app_id" content="{{ OPEN_GRAPH_FB_APP_ID }}"/>
        <meta property="og:site_name" content="{{ SITENAME }}" />
        <meta property="og:type" content="article"/>
        <meta property="og:title" content="{{ article.title|striptags|escape|breaking_spaces }}"/>
        <meta property="og:url" content="{{ SITEURL }}/{{ article.url }}"/>
        <meta property="og:description" content="{{ article.summary|striptags|escape }}"/>
        <meta property="article:published_time" content="{{ article.date.strftime("%Y-%m-%d") }}" />
        {% if article.category %}
            <meta property="article:section" content="{{ article.category }}" />
        {% endif %}
        {% for tag in article.tags %}
            <meta property="article:tag" content="{{ tag }}" />
        {% endfor %}
        {% if article.author %}
            <meta property="article:author" content="{{ article.author }}" />
        {% elif AUTHOR %}
            <meta property="article:author" content="{{ AUTHOR }}" />
        {% endif %}
        {% if article.og_image %}
            <meta property="og:image"
                  content="{{ SITEURL }}/{{ article.og_image }}"/>
        {% elif OPEN_GRAPH_IMAGE %}
            <meta property="og:image"
                  content="{{ SITEURL }}/{{ OPEN_GRAPH_IMAGE }}"/>
        {% endif %}
    {% endif %}
{% endblock %}

{% block canonical_rel %}
<link rel="canonical" href="{{ SITEURL }}/{{ article.url }}">
{% endblock %}

{% block breadcrumbs %}
    {% if DISPLAY_BREADCRUMBS %}
        <ol class="breadcrumb">
            <li><a href="{{ SITE_ROOT_URL }}" title="{{ SITENAME }}"><span class="fa fa-home fa-lg"></span></a></li>
            {% if MENUITEMS_2_AT %}
                <li><a href="{{ SITEURL }}/{{ MENUITEMS_2_AT_LINK }}" title="{{ MENUITEMS_2_AT }}">{{ MENUITEMS_2_AT }}</a></li>
            {% endif %}
            {% if DISPLAY_CATEGORY_IN_BREADCRUMBS %}
                <li><a href="{{ SITEURL }}/{{ article.category.url }}" title="{{ article.category }}">{{ article.category }}</a></li>
            {% endif %}
            <li class="active">{{ article.title | striptags }}</li>
        </ol>     
    {% endif %}
{% endblock %}

{% block content %}
    <section id="content">
        <article>
            {% if article.image %}
                <img class="featured-image image-process-article-feature" src="{{ SITEURL }}/{{ article.image|urlencode }}" alt="{{ article.title|striptags }}">
            {% elif CATEGORY_IMAGES and article.category in CATEGORY_IMAGES %}
                <img class="featured-image image-process-article-feature" src="{{ SITEURL }}/{{ CATEGORY_IMAGES[article.category]|urlencode }}"  alt="{{ article.category|striptags }}">              
            {% endif %}

            <header class="entry-header">
                <h1>
                    <a href="{{ SITEURL }}/{{ article.url }}"
                       rel="bookmark"
                       title="Permalink to {{ article.title|striptags }}">
                        {{ article.title|replace('&nbsp;', ' ') }}
                    </a>
                </h1>
            </header>
            <div class="entry-content">
                <div class="panel">
                    <div class="panel-body">
                        {% include "includes/article_info.html" %}
                    </div>
                </div>
                {{ article.content }}
            </div>
            <!-- /.entry-content -->
            {% include 'includes/neighbors.html' %}
            {% include 'includes/related-posts.html' %}
            {% include 'includes/addthis.html' %}
            {% include 'includes/comments.html' %}
        </article>
    </section>
{% endblock %}
