{% extends "base.html" %}

{% block title %}Error 404 - {{ SITENAME }}{%endblock%}}

{% block content %}
    <section id="content">
        <h1 class="post-title">
            Error 404: Page Note Found
        </h1>
        <section class="post-content">
            <p>Oops, we're lost...</p>
            <p>You're tried to land on a page that doesn't really exist.</p>
            </p>Go back to <a href="{{ SITE_ROOT_URL }}/">home</a> and try again?</section>
        </section>
    </section>
{% endblock %}
